import Vue from 'vue'
import VueResource from 'vue-resource'
import VPaginator from 'src/components/VPaginator'
import {mockedResponse, options} from './data.js'
Vue.use(VueResource)

console.log(mockedResponse, options)
describe('VPaginator.vue', () => {
  it('should render the paginator', () => {
    const vm = new Vue({
      data: { dummies: [] },
      template: '<div><v-paginator resource_url="" :resource.sync="dummies"></v-paginator></div>',
      components: { VPaginator }
    }).$mount()
    expect(vm.$el.querySelector('.v-paginator').textContent).to.contain('Previous')
  })
  it('should set pagination data correctly', () => {
    const vm = new Vue({
      data: { dummies: [], options: options },
      template: '<div><v-paginator resource_url="" :resource.sync="dummies" :options="options"></v-paginator></div>',
      components: { VPaginator }
    }).$mount()
    vm.$children[0].handleResponseData(mockedResponse)
    // expect that pagination data have been set correctly
    expect(vm.$children[0].next_page_url).to.equal(mockedResponse.nested.next_page_url)
    expect(vm.$children[0].next_page_url).to.not.equal('something else')
    expect(vm.$children[0].prev_page_url).to.equal(mockedResponse.nested.prev_page_url)
    expect(vm.$children[0].current_page).to.equal(mockedResponse.nested.current_page)
    expect(vm.$children[0].last_page).to.equal(mockedResponse.nested.last_page)
  })
  it('should fetch data correctly', () => {
    const vm = new Vue({
      data: { dummies: [], options: options },
      template: '<div><v-paginator resource_url="" :resource.sync="dummies" :options="options"></v-paginator></div>',
      components: { VPaginator }
    }).$mount()
    vm.$children[0].handleResponseData(mockedResponse)
    // check that response data have been reflected to current instance
    expect(vm.dummies).to.have.length(5)
  })
  it('should export nested value from object', () => {
    const vm = new Vue({
      data: { dummies: [], options: options },
      template: '<div><v-paginator resource_url="" :resource.sync="dummies" :options="options"></v-paginator></div>',
      components: { VPaginator }
    }).$mount()
    const value = vm.$children[0].getNestedValue({ nested: { inside: { object: { value: 'foo' } } } }, 'nested.inside.object.value')
    // check that response data have been reflected to current instance
    expect(value).to.equal('foo')
  })
})
